# jaq-bin

https://github.com/01mf02/jaq

jaq (pronounced /ʒaːk/, like _Jacques_) is a clone of
the JSON data processing tool [`jq`](https://jqlang.github.io/jq/).
It has a few features not present in `jq`, such as
support for the data formats YAML, CBOR, TOML, and XML.
jaq has an own [manual](https://gedenkt.at/jaq/manual/).
You can try jaq on the [playground](https://gedenkt.at/jaq/).

This pypi package provides precompiled binaries of `jaq` for various platforms.

## install

```sh
pip install jaq-bin
```
